pub enum Dir3 {
X,
Y,
Z,
NegX,
NegY,
NegZ,
}Expand description
A 3d direction.
Variants
Implementations
Sourceimpl Dir3
impl Dir3
pub const ALL: [Dir2; 4]
pub fn choose(rng: &mut impl RngExt) -> Dir3
pub fn from_dir(dir: Dir2) -> Dir3
pub fn to_dir(self) -> Option<Dir2>
pub fn from_vec3(vec: Vec3<i32>) -> Dir3
pub fn opposite(self) -> Dir3
Sourcepub fn rotate_axis_ccw(self, axis: Dir3) -> Dir3
pub fn rotate_axis_ccw(self, axis: Dir3) -> Dir3
Rotate counter clockwise around an axis by 90 degrees.
Sourcepub fn rotate_axis_cw(self, axis: Dir3) -> Dir3
pub fn rotate_axis_cw(self, axis: Dir3) -> Dir3
Rotate clockwise around an axis by 90 degrees.
Sourcepub fn cross(self, other: Dir3) -> Dir3
pub fn cross(self, other: Dir3) -> Dir3
Get a direction that is orthogonal to both directions, always a positive direction.
pub fn abs(self) -> Dir3
pub fn signum(self) -> i32
pub fn to_vec3(self) -> Vec3<i32>
pub fn is_positive(self) -> bool
pub fn is_negative(self) -> bool
Sourcepub fn select(self, vec: impl Into<Vec3<i32>>) -> i32
pub fn select(self, vec: impl Into<Vec3<i32>>) -> i32
Returns the component that the direction is parallell to
Sourcepub fn select_with(
self,
vec: impl Into<Vec3<i32>>,
other: impl Into<Vec3<i32>>,
) -> Vec3<i32>
pub fn select_with( self, vec: impl Into<Vec3<i32>>, other: impl Into<Vec3<i32>>, ) -> Vec3<i32>
Select one component the direction is parallel to from vec and select the other components from other
Sourcepub fn select_aabb<T>(self, aabb: Aabb<T>) -> T
pub fn select_aabb<T>(self, aabb: Aabb<T>) -> T
Returns the side of an aabb that the direction is pointing to
Sourcepub fn select_aabb_with<T>(
self,
aabb: Aabb<T>,
other: impl Into<Vec3<T>>,
) -> Vec3<T>
pub fn select_aabb_with<T>( self, aabb: Aabb<T>, other: impl Into<Vec3<T>>, ) -> Vec3<T>
Select one component from the side the direction is pointing to from aabr and select the other components from other
pub fn split_aabb_offset<T>(self, aabb: Aabb<T>, offset: T) -> [Aabb<T>; 2]
pub fn trim_aabb(self, aabb: Aabb<i32>, amount: i32) -> Aabb<i32>
pub fn extend_aabb(self, aabb: Aabb<i32>, amount: i32) -> Aabb<i32>